translate.lang.factory

Package translate :: Package lang :: Module factory |
[hide private]
[frames] | no frames]

# Module factory

source code

This module provides a factory to instantiate language classes.

Functions | [hide private]
getlanguage(code) This returns a language class. | source code

Variables | [hide private]
| prefix = ``'``code_``'``
| __package__ = ``'``translate.lang``'``

Imports: common, data

Function Details | [hide private]

### getlanguage(code) | source code
This returns a language class. Parameters: `code` - The ISO 639 language code